chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.action === 'fillBets') {
        const betsArray = message.betsArray;
        performActionsSequentially(betsArray).then(result => {
            sendResponse(result);
        }).catch(error => {
            console.error('Błąd w contentScript:', error);
            sendResponse({ success: false, error: error.message });
        });
        // Zwróć true, aby wskazać, że odpowiedź będzie wysłana asynchronicznie
        return true;
    }
});

async function performActionsSequentially(betsArray) {
    try {
        function delay(ms) {
            return new Promise(resolve => setTimeout(resolve, ms));
        }

        // Sprawdzenie, czy jesteśmy na właściwej podstronie z formularzem
        const deleteButtonExists = document.querySelector('.action-button .icon-delete') !== null;
        if (!deleteButtonExists) {
            return { success: false, errorType: 'incorrectPage' };
        }

        // Funkcje pomocnicze
        async function uncheckToggle() {
            const toggleElement = document.querySelector('.toggle.checked');
            if (toggleElement) {
                toggleElement.click();
                await delay(500);
            }
        }

        async function clickAllDeleteButtons() {
            let deleteButtons;
            let attempts = 0;
            const maxAttempts = 10;

            while ((deleteButtons = document.querySelectorAll('.action-button .icon-delete')).length > 1 && attempts < maxAttempts) {
                deleteButtons[0].click();
                await delay(250);
                attempts++;
            }
        }

        async function ensureCorrectNumberOfRows(expectedCount) {
            const maxAllowedBets = 10; // Maksymalna liczba zakładów dozwolona na stronie

            let currentCount = document.querySelectorAll('.action-button .icon-delete').length;
            let attempts = 0;
            const maxAttempts = 10;

            while (currentCount < expectedCount && currentCount < maxAllowedBets && attempts < maxAttempts) {
                const addBetButton = document.querySelector('.action-control.add-bet button');
                if (addBetButton) {
                    addBetButton.click();
                    await delay(250);
                } else {
                    break;
                }
                const newCount = document.querySelectorAll('.action-button .icon-delete').length;

                if (newCount === currentCount) {
                    attempts++;
                } else {
                    attempts = 0;
                }

                currentCount = newCount;
            }

            return { currentCount };
        }

        async function fillBetsAndSave(betsArray, availableBets) {
            const editButtons = document.querySelectorAll('.icon-edit');
            availableBets = Math.min(availableBets, editButtons.length, betsArray.length);

            for (let i = 0; i < availableBets; i++) {
                editButtons[i].click();
                await delay(250);

                const manualInputs = document.querySelectorAll('.enter-manually input');
                const numbers = betsArray[i].split(/[\s,]+/);
                for (let j = 0; j < numbers.length; j++) {
                    if (manualInputs[j]) {
                        manualInputs[j].value = numbers[j];
                        const event = new Event('input', { bubbles: true });
                        manualInputs[j].dispatchEvent(event);
                        await delay(50);
                    }
                }

                const saveButton = document.querySelector('.save button');
                if (saveButton) {
                    saveButton.click();
                    await delay(250);
                } else {
                    break;
                }
            }

            return { success: true, availableBets };
        }

        // Wykonanie sekwencji akcji
        await uncheckToggle();
        await clickAllDeleteButtons();
        const rowCheckResult = await ensureCorrectNumberOfRows(betsArray.length);
        const currentCount = rowCheckResult.currentCount;

        await fillBetsAndSave(betsArray, currentCount);

        if (currentCount < betsArray.length) {
            // Nie udało się dodać wszystkich zakładów
            return { success: false, errorType: 'exceededMaxBets', currentCount };
        } else {
            return { success: true };
        }

    } catch (error) {
        console.error('Błąd w performActionsSequentially:', error);
        return { success: false, error: error.message };
    }
}
