document.addEventListener('DOMContentLoaded', () => {
    const betsTextarea = document.getElementById('bets');
    const submitBtn = document.getElementById('submitBtn');
    const errorMessage = document.getElementById('error-message'); 

    const api = chrome;

    // Funkcja do poprawnej odmiany słowa "zakład"
    function getZakladyText(count) {
        if (count === 1) return 'zakład';
        if (count >= 2 && count <= 4) return 'zakłady';
        return 'zakładów';
    }

    // Funkcja do wyświetlania komunikatów
    function showErrorMessage(message) {
        errorMessage.textContent = message;
        errorMessage.style.display = "block";
    }

    // Ukrywanie komunikatu o błędzie przed każdą nową operacją
    function hideErrorMessage() {
        errorMessage.textContent = '';
        errorMessage.style.display = 'none';
    }

    // Funkcja do włączania/wyłączania przycisku "Prześlij"
    function toggleSubmitButton(enable) {
        submitBtn.disabled = !enable;
        if (enable) {
            updateSubmitButtonText();
            submitBtn.style.backgroundColor = '#4CAF50'; // Zielony
            submitBtn.style.cursor = 'pointer';
        } else {
            submitBtn.style.backgroundColor = 'gray';
            submitBtn.style.cursor = 'not-allowed';
        }
    }

    // Aktualizacja tekstu na przycisku "Prześlij"
    function updateSubmitButtonText() {
        const betsText = betsTextarea.value.trim();
        const betLines = betsText ? betsText.split('\n').filter(Boolean).length : 0;
        submitBtn.textContent = betLines > 0 ? `Prześlij ${betLines} ${getZakladyText(betLines)}` : 'Prześlij';
    }

    // Przywróć zapisaną zawartość z localStorage po otwarciu popupu
    api.storage.local.get('betsText', (result) => {
        if (result.betsText) {
            betsTextarea.value = result.betsText;
            updateSubmitButtonText();
        }
    });

    // Zapisuj zawartość textarea do localStorage za każdym razem, gdy użytkownik coś wpisuje
    betsTextarea.addEventListener('input', () => {
        api.storage.local.set({ betsText: betsTextarea.value });
        updateSubmitButtonText();
    });

    submitBtn.addEventListener('click', () => {
        hideErrorMessage(); // Ukryj poprzednie komunikaty o błędzie
        toggleSubmitButton(false); // Wyłącz przycisk podczas pracy

        const betsText = betsTextarea.value;
        const betsArray = betsText.split('\n').map(bet => bet.trim()).filter(Boolean);

        api.tabs.query({ active: true, currentWindow: true }, (tabs) => {
            const currentTab = tabs[0];

            // Sprawdzenie, czy domena to lotto.pl
            if (!currentTab.url.includes("lotto.pl")) {
                showErrorMessage(`Ta wtyczka działa tylko na stronie www.lotto.pl`);
                toggleSubmitButton(true); // Ponownie włącz przycisk
                return;
            }

            // Wyślij wiadomość do contentScript
            api.tabs.sendMessage(currentTab.id, { action: 'fillBets', betsArray }, (response) => {
                toggleSubmitButton(true); // Włącz przycisk po zakończeniu działania skryptu

                if (response && response.success) {
                    // Sukces
                } else if (response && !response.success) {
                    if (response.errorType === 'incorrectPage') {
                        showErrorMessage(`Proszę upewnić się, że znajdujesz się na formularzu do zawierania zakładów Lotto.`);
                    } else if (response.errorType === 'exceededMaxBets') {
                        const currentCount = response.currentCount;
                        const failedCount = betsArray.length - currentCount;
                        showErrorMessage(`Tylko pierwsze ${currentCount} ${getZakladyText(currentCount)} mogą zostać wprowadzone. Nie udało się dodać ${failedCount} ${getZakladyText(failedCount)}.`);
                    } else if (response.error) {
                        showErrorMessage(`Wystąpił błąd: ${response.error}`);
                    } else {
                        showErrorMessage(`Wystąpił nieoczekiwany błąd podczas wprowadzania zakładów.`);
                    }
                } else {
                    showErrorMessage(`Wystąpił nieoczekiwany błąd podczas wprowadzania zakładów.`);
                }
            });
        });
    });
});